"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const stream_1 = require("stream");
const ingress_js_1 = __importDefault(require("./ingress.js"));
const shot_1 = require("@hapi/shot");
(0, vitest_1.describe)('ingress', () => {
    (0, vitest_1.it)('route return types', async () => {
        const app = (0, ingress_js_1.default)(), { Route, Routes } = app;
        let Greet = class Greet {
            greeting(name) {
                return Promise.resolve(`Hello ${name}`);
            }
            jsonHello(name) {
                return { Hello: name };
            }
            htmlHello(name) {
                return /*html*/ `
          <h1>Hello ${name}</h1>
        `.trim();
            }
            bytesHello(name) {
                return Buffer.from('Hello ' + name);
            }
            streamHello(name) {
                const reads = [null, name, ' ', 'Hello'];
                return new stream_1.Readable({
                    read() {
                        this.push(reads.pop());
                    },
                });
            }
            responseHello(name) {
                return new Response(`Hello ${name}`);
            }
            fetchHello(req, name) {
                (0, vitest_1.expect)(req.url).toEqual(`http://localhost/greet/fetch/${name}`);
                return new Response(`Hello ${name}`);
            }
            fetchError(name) {
                const err = new CustomError(`Hello ${name}`);
                err.statusCode = 502;
                return err;
            }
            throwError(name) {
                throw new CustomError(`Hello ${name}`);
            }
        };
        __decorate([
            Route.Get('/text/:name'),
            __param(0, Route.Param('name')),
            __metadata("design:type", Function),
            __metadata("design:paramtypes", [String]),
            __metadata("design:returntype", void 0)
        ], Greet.prototype, "greeting", null);
        __decorate([
            Route.Get('/json/:name'),
            __param(0, Route.Param('name')),
            __metadata("design:type", Function),
            __metadata("design:paramtypes", [String]),
            __metadata("design:returntype", void 0)
        ], Greet.prototype, "jsonHello", null);
        __decorate([
            Route.Get('/html/:name'),
            __param(0, Route.Param('name')),
            __metadata("design:type", Function),
            __metadata("design:paramtypes", [String]),
            __metadata("design:returntype", void 0)
        ], Greet.prototype, "htmlHello", null);
        __decorate([
            Route.Get('/bytes/:name'),
            __param(0, Route.Param('name')),
            __metadata("design:type", Function),
            __metadata("design:paramtypes", [String]),
            __metadata("design:returntype", void 0)
        ], Greet.prototype, "bytesHello", null);
        __decorate([
            Route.Get('/stream/:name'),
            __param(0, Route.Param('name')),
            __metadata("design:type", Function),
            __metadata("design:paramtypes", [String]),
            __metadata("design:returntype", void 0)
        ], Greet.prototype, "streamHello", null);
        __decorate([
            Route.Get('/response/:name'),
            __param(0, Route.Param('name')),
            __metadata("design:type", Function),
            __metadata("design:paramtypes", [String]),
            __metadata("design:returntype", void 0)
        ], Greet.prototype, "responseHello", null);
        __decorate([
            Route.Get('/fetch/:name'),
            __param(1, Route.Param('name')),
            __metadata("design:type", Function),
            __metadata("design:paramtypes", [Request, String]),
            __metadata("design:returntype", void 0)
        ], Greet.prototype, "fetchHello", null);
        __decorate([
            Route.Get('/error/:name'),
            __param(0, Route.Param('name')),
            __metadata("design:type", Function),
            __metadata("design:paramtypes", [String]),
            __metadata("design:returntype", void 0)
        ], Greet.prototype, "fetchError", null);
        __decorate([
            Route.Get('/throw/:name'),
            __param(0, Route.Param('name')),
            __metadata("design:type", Function),
            __metadata("design:paramtypes", [String]),
            __metadata("design:returntype", void 0)
        ], Greet.prototype, "throwError", null);
        Greet = __decorate([
            Routes('/greet')
        ], Greet);
        await app.start();
        void Greet;
        const response9 = await (0, shot_1.inject)(app.driver, '/greet/throw/world');
        (0, vitest_1.expect)(response9.headers['content-length']).toEqual('72');
        (0, vitest_1.expect)(response9.headers['content-type']).toEqual('application/json');
        (0, vitest_1.expect)(response9.statusCode).toEqual(500);
        (0, vitest_1.expect)(response9.payload).toEqual(JSON.stringify({
            error: { code: 'INTERNAL_ERROR', status: 500, message: 'Hello world' },
        }));
        const response8 = await (0, shot_1.inject)(app.driver, '/greet/error/world');
        (0, vitest_1.expect)(response8.headers['content-length']).toEqual('72');
        (0, vitest_1.expect)(response8.headers['content-type']).toEqual('application/json');
        (0, vitest_1.expect)(response8.statusMessage).toEqual('Internal Server Error');
        (0, vitest_1.expect)(response8.statusCode).toEqual(502);
        (0, vitest_1.expect)(response8.payload).toEqual(JSON.stringify({
            error: { code: 'INTERNAL_ERROR', status: 502, message: 'Hello world' },
        }));
        const response7 = await (0, shot_1.inject)(app.driver, '/greet/fetch/world');
        (0, vitest_1.expect)(response7.headers['content-length']).toEqual(undefined);
        (0, vitest_1.expect)(response7.headers['content-type']).toEqual('text/plain;charset=UTF-8');
        (0, vitest_1.expect)(response7.statusCode).toEqual(200);
        (0, vitest_1.expect)(response7.payload).toEqual('Hello world');
        const response6 = await (0, shot_1.inject)(app.driver, '/greet/response/world');
        (0, vitest_1.expect)(response6.headers['content-length']).toEqual(undefined);
        (0, vitest_1.expect)(response6.headers['content-type']).toEqual('text/plain;charset=UTF-8');
        (0, vitest_1.expect)(response6.statusCode).toEqual(200);
        (0, vitest_1.expect)(response6.payload).toEqual('Hello world');
        const response5 = await (0, shot_1.inject)(app.driver, '/greet/stream/world');
        (0, vitest_1.expect)(response5.headers['content-length']).toEqual(undefined);
        (0, vitest_1.expect)(response5.headers['content-type']).toEqual('application/octet-stream');
        (0, vitest_1.expect)(response5.statusCode).toEqual(200);
        (0, vitest_1.expect)(response5.payload).toEqual('Hello world');
        const response4 = await (0, shot_1.inject)(app.driver, '/greet/bytes/world');
        (0, vitest_1.expect)(response4.headers['content-length']).toEqual('11');
        (0, vitest_1.expect)(response4.headers['content-type']).toEqual('application/octet-stream');
        (0, vitest_1.expect)(response4.statusCode).toEqual(200);
        (0, vitest_1.expect)(response4.payload).toEqual('Hello world');
        const response3 = await (0, shot_1.inject)(app.driver, '/greet/html/world');
        (0, vitest_1.expect)(response3.headers['content-length']).toEqual('20');
        (0, vitest_1.expect)(response3.headers['content-type']).toEqual('text/plain;charset=UTF-8');
        (0, vitest_1.expect)(response3.statusCode).toEqual(200);
        (0, vitest_1.expect)(response3.payload).toEqual(`<h1>Hello world</h1>`);
        const response2 = await (0, shot_1.inject)(app.driver, '/greet/json/world');
        (0, vitest_1.expect)(response2.headers['content-length']).toEqual('17');
        (0, vitest_1.expect)(response2.headers['content-type']).toEqual('application/json');
        (0, vitest_1.expect)(response2.statusCode).toEqual(200);
        (0, vitest_1.expect)(response2.payload).toEqual('{"Hello":"world"}');
        const response = await (0, shot_1.inject)(app.driver, '/greet/text/world');
        (0, vitest_1.expect)(response.headers['content-length']).toEqual('11');
        (0, vitest_1.expect)(response.headers['content-type']).toEqual('text/plain;charset=UTF-8');
        (0, vitest_1.expect)(response.statusCode).toEqual(200);
        (0, vitest_1.expect)(response.payload).toEqual('Hello world');
    });
});
class CustomError extends Error {
    contentType = 'application/json';
    statusCode = 500;
    statusMessage = 'Internal Server Error';
    constructor(message) {
        super(message);
    }
    toString() {
        return JSON.stringify({
            error: {
                code: 'INTERNAL_ERROR',
                status: this.statusCode,
                message: this.message,
            },
        });
    }
}
//# sourceMappingURL=route-return-types.test.js.map